@@ -5,8 +5,9 @@ import logging
 from typing import List, Dict, Any, Union, Iterable, Tuple, Callable
 
 import pandas as pd
-from ete3 import Tree, TreeNode, NodeStyle, TreeStyle, TextFace, RectFace
+from ete3 import Tree, TreeNode
 
+from genomics_data_index.ete3treeview import NodeStyle, TreeStyle, TextFace, RectFace
 from genomics_data_index.api.query.SamplesQuery import SamplesQuery
 from genomics_data_index.api.viewer.TreeSamplesVisual import TreeSamplesVisual
 from genomics_data_index.api.viewer.samples_visuals.AnnotateTreeSamplesVisual import AnnotateTreeSamplesVisual
@@ -16,8 +17,12 @@ from genomics_data_index.api.viewer.samples_visuals.HighlightTreeSamplesVisual i
 
 logger = logging.getLogger(__name__)
 
-DEFAULT_NODE_STYLE = NodeStyle()
-DEFAULT_NODE_STYLE['size'] = 0
+try:
+    DEFAULT_NODE_STYLE = NodeStyle()
+    DEFAULT_NODE_STYLE['size'] = 0
+except Exception as e:
+    logger.warning(e)
+    DEFAULT_NODE_STYLE = None
 
 
 class TreeStyler:
